AI.Agent.Coordinator.Frippery (fnord v0.9.29)

Frippery and furbelows for the Coordinator agent. This module contains functions that provide fluff and flavor to the Coordinator's interactions, like greeting the user colorfully and appending the MOTD to the response.

Summary

Types

state()

@type state() :: AI.Agent.Coordinator.state()

t()

@type t() :: AI.Agent.Coordinator.t()

Functions

get_motd(state)

@spec get_motd(state()) :: state()

greet(state)

@spec greet(t()) :: t()

hint_disabled_external_configs()

log_available_frobs()

log_available_mcp_tools()

log_available_skills()