AI.Agent.Coordinator.Notes (fnord v0.9.29)

Notes-specific behaviors for AI.Agent.Coordinator, including generating messages related to note-taking and management.

Summary

Functions

When starting a new conversation session, this ingests the user's prompt into the notes infrastructure for later processing.

Retrieves relevant notes based on the user's question. It then appends an assistant message reflecting on the retrieved notes to the conversation. Finally, it updates the state with the retrieved notes for use in subsequent steps.

Types

state()

@type state() :: AI.Agent.Coordinator.state()

Functions

init(state)

@spec init(state()) :: state()

When starting a new conversation session, this ingests the user's prompt into the notes infrastructure for later processing.

lore_me_up(state)

@spec lore_me_up(t()) :: no_return()

Retrieves relevant notes based on the user's question. It then appends an assistant message reflecting on the retrieved notes to the conversation. Finally, it updates the state with the retrieved notes for use in subsequent steps.