AI.Agent.Coordinator.Test (fnord v0.9.29)

Test-mode-specific behaviors for AI.Agent.Coordinator, including generating messages related to testing. Test mode is a special case that lets the dev do manual "integration testing" to verify tool functionality and integration with the agent code.

Summary

Functions

get_response(state)

@spec get_response(t()) :: {:error, :testing}

is_testing?(map)

@spec is_testing?(t()) :: boolean()