AI.Tools.ApplyPatch (fnord v0.9.29)
View SourceNote: The current crop of LLMs appear to be extremely overfitted to a tool called "apply_patch" for making code changes. This module is me giving up on trying to prevent them from using the cmd_tool to call a non-existent apply_patch command and instead trying rolling with it.