AI.Tools.SelfHelp.Cli (fnord v0.9.29)
View SourceA tool that returns the fnord spec to the LLM to help it understand how to use the CLI and what commands are available. This allows the LLM to assist the user with questions about its own capabilities.