AI.Agent.Coordinator.Frippery (fnord v0.9.29)
View SourceFrippery and furbelows for the Coordinator agent. This module contains functions that provide fluff and flavor to the Coordinator's interactions, like greeting the user colorfully and appending the MOTD to the response.
Summary
Types
@type state() :: AI.Agent.Coordinator.state()
@type t() :: AI.Agent.Coordinator.t()