AI.Agent.Coordinator.Test (fnord v0.9.29)
View SourceTest-mode-specific behaviors for AI.Agent.Coordinator, including generating messages related to testing. Test mode is a special case that lets the dev do manual "integration testing" to verify tool functionality and integration with the agent code.
Summary
Functions
@spec get_response(t()) :: {:error, :testing}
@spec is_testing?(t()) :: boolean()