AI.Tools.SaveSkill (fnord v0.9.29)
View SourceSave a new skill definition either into the current project's skills directory or into the user-global skills directory.
The coordinator can use this tool to persist skill TOML files under:
project scope: ~/.fnord/projects/<project>/skills/<name>.toml
global scope: ~/.fnord/skills/<name>.toml
Safety rules:
- The tool is synchronous.
- It requires explicit user confirmation via
UI.confirm/2. - For project scope, it refuses to create a project skill if a user-defined skill with the same name already exists in
~/fnord/skills(because user definitions override project definitions). - For global scope, it writes directly to the user skills directory (overwriting existing entries if any).