Services.Task.List (fnord v0.9.29)
View SourceRepresents a task list with an identifier, optional description, and a list of tasks. Provides core operations for creating and manipulating task lists.
Summary
Functions
Adds a task to the end of the task list.
Creates a new TaskList with the given id and optional description.
Pushes a task to the front of the task list.
Resolves tasks with the given task_id by updating their outcome and result.
Only tasks in todo state are updated.
Converts the task list to a string, including the header and each task.
If detail? is true, includes task results for done/failed tasks.
Types
Functions
Adds a task to the end of the task list.
Creates a new TaskList with the given id and optional description.
Pushes a task to the front of the task list.
@spec resolve(t(), binary(), :done | :failed, any()) :: {:ok, t()} | {:error, :already_resolved | :not_found}
Resolves tasks with the given task_id by updating their outcome and result.
Only tasks in todo state are updated.
Converts the task list to a string, including the header and each task.
If detail? is true, includes task results for done/failed tasks.