Skills.Skill (fnord v0.9.29)
View SourceA single skill definition loaded from a TOML file.
Skills are defined on disk as TOML and loaded at runtime.
Fields in the struct reflect the stable skill schema:
name,description,model,tools,system_promptare requiredresponse_formatis optional
Validation is performed when loading a skill from TOML.
Summary
Functions
Convert a decoded TOML map into a validated skill struct.
Types
Functions
@spec from_map(map()) :: {:ok, t(), [warning()]} | {:error, decode_error()}
Convert a decoded TOML map into a validated skill struct.
The TOML parser is expected to decode keys as strings.