Store.Project.Notes (fnord v0.9.29)
View SourceSummary
Functions
Returns the notes file path for the given project.
Reads notes for the given project.
Resets the notes file for the given project.
Writes notes content for the given project.
Functions
@spec file_path(Store.Project.t() | binary()) :: {:ok, String.t()} | {:error, term()}
Returns the notes file path for the given project.
The project may be provided as a %Store.Project{} or as a project name
binary, which will be resolved via Store.get_project/1.
@spec read(Store.Project.t() | binary()) :: {:ok, String.t()} | {:error, term()}
Reads notes for the given project.
The project may be provided as a %Store.Project{} or as a project name
binary, which will be resolved via Store.get_project/1.
@spec reset(Store.Project.t() | binary()) :: :ok | {:error, term()}
Resets the notes file for the given project.
The project may be provided as a %Store.Project{} or as a project name
binary, which will be resolved via Store.get_project/1.
@spec write(Store.Project.t() | binary(), iodata()) :: :ok | {:error, term()}
Writes notes content for the given project.
The project may be provided as a %Store.Project{} or as a project name
binary, which will be resolved via Store.get_project/1.